@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,7 +24,7 @@
 #include "qmmp_export.h"
 
 #define QMMP_VERSION_MAJOR 1
-#define QMMP_VERSION_MINOR 3
+#define QMMP_VERSION_MINOR 4
 #define QMMP_VERSION_PATCH 3
 #define QMMP_VERSION_STABLE 1
 
@@ -39,6 +39,15 @@
 #define QStringToFileName(s) s.toLocal8Bit().constData()
 #endif
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
+// this adds const to non-const objects (like std::as_const)
+template <typename T>
+Q_DECL_CONSTEXPR typename std::add_const<T>::type &qAsConst(T &t) noexcept { return t; }
+// prevent rvalue arguments:
+template <typename T>
+void qAsConst(const T &&) = delete;
+#endif
+
 
 /*! @brief The Qmmp class stores global settings and enums.
  * @author Ilya Kotov <forkotov02@ya.ru>
@@ -104,7 +113,7 @@ public:
      */
     enum AudioFormat
     {
-        PCM_UNKNOWM = -1, /*!< Unknown format */
+        PCM_UNKNOWN = -1, /*!< Unknown format */
         PCM_S8 = 0, /*!< Signed 8 bit */
         PCM_U8,     /*!< Unsigned 8 bit */
         PCM_S16LE,  /*!< Signed 16 bit Little Endian */
